#ifndef ACTIONDETECTOR_H
#define ACTIONDETECTOR_H

#include "utils.h"

enum ErrorCode {
    NO_ERROR                        = 0,
    ACTION_TYPE_ERROR               = 1,
    INPUT_DATA_ERROR                = 2,
    ACTION_DETECTOR_ERROR           = 3,
    FACE_DETECTOR_ERROR             = 4,
    HEAD_POSE_ESTIMATOR_ERROR       = 5,
    FACE_LANDMARK_DETECTOR_ERROR    = 6,
    NO_FACE                         = 7,
    TOO_BIG_FACE                    = 8,
    TOO_SMALL_FACE                  = 9,
    TOO_MANY_FACE                   = 10,
    FACE_NOT_IN_CENTER              = 11,
    FACE_PICTURE_ABNORMAL           = 12,
    TOO_LARGE_PITCH_ANGLE           = 13,
    TOO_LARGE_YAW_ANGLE             = 14,
    TOO_LARGE_ROLL_ANGLE            = 15,
    TOO_STRONG_LIGHT                = 16,
    TOO_WEAK_LIGHT                  = 17,
    EYE_OCCLUSION                   = 18,
    MOUTH_OCCLUSION                 = 19,
    FACE_OCCLUSION                  = 20,
};

enum ActionType {
    NO_ACTION   = 0,
    TURN_LEFT   = 1,
    TURN_RIGHT  = 2,
    NOD         = 3,
    OPEN_MOUTH  = 4,
    BLINK_EYE   = 5
};

typedef struct {
    int open_mouth_status;
    int blink_eye_status;
    int turn_left_status;
    int turn_right_status;
    int nod_status;
}ActionStatus;


class ActionDetector {
public:
    ActionDetector(const std::vector<std::string> &model_path);
    ~ActionDetector();
    /* run algorithm */
    ErrorCode run(const cv::Mat &image); // find out all the action types.
    ErrorCode run(const cv::Mat &image, const ActionType &input_action_type); // find out the setting action type.
    ActionStatus getOutput();
    std::vector<cv::Mat> getFaceImage();

public:
    bool is_save_face_image; // true: save, false: not save;
private:
    int error_code;
    int input_action_type; // the setting action type.
    void *algorithm_handle;

};

#endif //ACTIONDETECTOR_H
