//
//  HuaweiFaceSDKManager.h
//  HuaweiDetectionSDK
//
//  Created by Huawei on 2020/8/8.
//  Copyright © 2020 Huawei. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "HWFAConfigItem.h"


NS_ASSUME_NONNULL_BEGIN

@interface FaceAntispoofingSdk : NSObject

/**
 该类为一个单例，需要先获得单例对象再进行后续操作
*/
+ (instancetype)getInstance;

/**
 检测结果回调
 */
@property (nonatomic, copy) VerifyResult verifyResult;

/**
 最后一次结果
 */
@property (assign, nonatomic) BOOL lastDetectResult;

/** SDK远程检测服务端接口参数*/

/**
 检测动作类型集合
 */
@property (readonly, strong, nonatomic) NSMutableArray *detectArr;

/**
 根据华为云TOKEN接口动态请求获取
 */
@property (readonly, strong, nonatomic) NSString *sdkToken;

/**
 检测动作类型
 */
@property (assign, nonatomic) FaceDetectType detectType;

/**
 配置信息
 */
@property (readonly, strong, nonatomic) HWFAConfigItem *configItem;

/**
 @param configItem     参数配置，详见：HWFAConfigItem
 */

-(void)initSdkWithConfigItem:(HWFAConfigItem *)configItem;

/**
 启动SDK活体检测页面
 @param sdkToken           根据华为云TOKEN接口动态请求获取
 @param verifyResult            进行活体检测结果回调。
 */
- (void)startSdkToken:(NSString *)sdkToken verifyResult:(VerifyResult)verifyResult;

/**
 初始化当前需要进行的动作
 */
- (FaceDetectType)getNowDetect;

/** 获取随机的行为模式*/
- (void)setupRandomDetectArr;

- (void)releaseInstance;

@end

NS_ASSUME_NONNULL_END
