//
//  HWFAConfig.h
//  HuaweiFaceAntispoofingLibrary
//
//  Created by liuzhao on 2021/7/27.
//  Copyright © 2021 Somer.King. All rights reserved.
//
#import <Foundation/Foundation.h>
#ifndef HWFAConfig_h
#define HWFAConfig_h

/**
 检查类型
 */
typedef NS_ENUM(NSInteger, FaceDetectType) {
    FaceDetectTypeRandom = 1 << 0,   // 随机检测(五个动作中随机检测)
    FaceDetectTypeTurnLeft = 1 << 1, // 向左偏头
    FaceDetectTypeTurnRight = 1 << 2,// 向右偏头
    FaceDetectTypeNod = 1 << 3,      // 点头
    FaceDetectTypeOpenMouth = 1 << 4,// 张张嘴
    FaceDetectTypeBlinkEye = 1 << 5  // 眨眨眼
};

/**
 检测错误码类型
 */
typedef NS_ENUM(NSInteger, VerifyError) {
    VerifyErrorSDKInitError = 0,            // SDK授权失败
    VerifyErrorTimeout,                     // 超时
    VerifyErrorCancel,                      // 取消
    VerifyErrorRemoteError,                 // 远端检测失败
    VerifyErrorSimilarityBlowThreshold,     // 相似度低于阈值
    VerifyErrorIdNumberNotMatchName,        // 认证信息不一致，姓名与身份证号码不一致
    VerifyErrorVerifyINfoNotMatchIdInfo,    // 认证信息不一致，身份证照片信息与需认证的身份信息不一致
    VerifyErrorFaceNotMatchIdInfo,          // 人脸与身份信息不符
    VerifyErrorQualityOrFormatError,        // 人脸图像质量或格式问题
    VerifyErrorNoFaceOrMoreFace,            // 未检测到人脸或检测到多张脸
    VerifyErrorNoImageInDatabase,           // 证件照不存在，属于数据源问题
    VerifyErrorNoIdInfoInDatabase,          // 认证中心数据源无此身份信息
    VerifyErrorOrderIdIsNoneOrExpired,      // order id不存在或者order id过期
    VerifyErrorFaceDetectError,             // 人脸检测错误
    VerifyErrorIdCardCannotRecognize,       // 身份证OCR无法识别
    VerifyErrorImageCannotUse,              // 图片不可用
    VerifyErrorServerError,                 // 服务器异常
};


/**
SDK检测结果回调代码块
@param verified               活体验证是否成功，YES：成功
@param VerifyError        活体验证错误码VerifyError类型
@param imageStr              活体验证成功后返回的图片base64字符串
@param errorMsg               活体验证错误信息
*/
typedef void (^VerifyResult)(BOOL verified, VerifyError VerifyError, NSString * _Nullable imageStr, NSString *errorMsg);


#endif /* HWFAConfig_h */
